# gray-matter [![NPM version](https://badge.fury.io/js/gray-matter.svg)](http://badge.fury.io/js/gray-matter)

> A simple to use and extend front matter library. Supports parsing and extracting YAML, JSON, TOML or Coffee Front-Matter, with options to set custom delimiters.

Used by [assemble](https://github.com/assemble/assemble), [verb](https://github.com/assemble/verb), and thousands of other projects!

**v0.5.0 has breaking changes!**

* YAML is now parsed using the `.safeLoad()` method from [js-yaml](http://github.com/nodeca/js-yaml).
* To parse coffee, CSON or javascript front matter, you must set `options.eval` to true.
* `stringify()` has been renamed to `toJSON()`
* `stringifyYAML()` has been renamed to `toYAML()`


## Highlights

* Reliable and battle-tested. 
* Will extract and parse:
  * [YAML](http://github.com/nodeca/js-yaml)
  * [JSON](http://en.wikipedia.org/wiki/Json)
  * [TOML](http://github.com/mojombo/toml)
  * [CoffeeScript](http://coffeescript.org) when `options.eval` is set to `true`
  * [CSON](https://github.com/bevry/cson) when `options.eval` is set to `true`
  * JavaScript: when `options.eval` is set to `true`
* Easy to add additional parsers! pull requests welcome!

#### TOC
<!-- toc -->

## Install
### Install with [npm](npmjs.org)

```bash
npm i gray-matter --save
```
### Install with [bower](https://github.com/bower/bower)

```bash
bower install gray-matter --save-dev
```

## Usage

```js
var matter = require('gray-matter');
console.log(matter('---\ntitle: foo\n---\nbar');
//=> {data: {title: 'foo'}, content: 'bar', orig: '---\ntitle: foo\n---\nbar'}
```

## API
## [matter](index.js#L47)

Expects a string and returns and object:

* `str` **{String}**: The string to parse    
* `options` **{Object}**: Object of options    
* `returns` **{Object}** `file`: Object with the following properties.  

```js
matter('---\ntitle: Blog\n---\nThis is content.');
```

Returns:

```json
{
  "data": {"title": "Blog"},
  "content": "This is content.",
  "original": "---\ntitle: Blog\n---\nThis is content."
}
```

## [.read](index.js#L109)

Read a file then pass the string and `options` to `matter()` for parsing:

* `filepath` **{String}**    
* `options` **{Object}**    
* `returns` **{Object}** `file`: Same object as `matter()`, with an additional `path` property  

```js
matter.read('file.md');
```

Returns something like:

```json
{
  "data": {"title": "Blog"},
  "content": "This is content.",
  "original": "---\ntitle: Blog\n---\nThis is content."
}
```

## [.exists](index.js#L130)

Return `true` if front-matter exists.

* `str` **{String}**: The string to parse    
* `options` **{Object}**: Options to pass to `matter()`    
* `returns` **{Boolean}** `true`: or `false`  

```js
matter.exists(str);
```

## [.extend](index.js#L150)

Extend and stringify **YAML** front matter. Takes an object as the second parameter, and returns either the extended, stringified object (YAML), or if no front matter is found an empty string is returned.

* `str` **{String}**: The string to parse    
* `obj` **{Object}**: The object to use to extend the front matter.    
* `returns` **{String}**: String with extended YAML front matter.  

```js
matter.extend(str, obj);
```

## [.reconstruct](index.js#L175)

A convenience wrapper around the `matter()` and `matter.extend()` methods.

* `str` **{String}**: The string to parse    
* `obj` **{Object}**: The object to use to extend the front matter.    
* `returns` **{String}**: Original string with extended front matter.  

Extends YAML front matter, then re-assembles front matter with
the content of the file.

```js
matter.reconstruct(str, obj);
```

## [.toJSON](index.js#L190)

* `str` **{String}**    
* `options` **{Object}**    
* `returns` **{Object}**: Parsed front matter as JSON.  

Convenience wrapper around the `matter(str).data()` method.

## [.toYAML](index.js#L203)

* `str` **{String}**    
* `options` **{Object}**    
* `returns` **{String}**: Stringified YAML.  

Stringify parsed front matter back to YAML.


## Options
__async_helper_id__wnyS0VRoq9lszTfEFhYyEHJkzUbnN0NnP7jzbFY7lk__



## Authors

**Jon Schlinkert**
 
+ [github/assemble](https://github.com/assemble)
+ [twitter/assemble](http://twitter.com/assemble) 

## License
Copyright (c) 2014 Jon Schlinkert  
Released under the MIT license

***

_This file was generated by [verb](https://github.com/jonschlinkert/verb) on November 11, 2014._


[js-yaml]: https://github.com/nodeca/js-yaml
[coffee-script]: https://github.com/jashkenas/coffeescript
[toml-node]: https://github.com/BinaryMuse/toml-node